# rufffmt

Atomic formatting and import sorting with Ruff

[![version](https://img.shields.io/pypi/v/rufffmt.svg)](https://pypi.org/project/rufffmt)
[![license](https://img.shields.io/pypi/l/rufffmt.svg)](https://github.com/amyreese/rufffmt/blob/main/LICENSE)


Install
-------

```shell-session
$ pip install rufffmt
```


Usage
-----

Format some files:

```shell-session
$ rufffmt format <path> [...]
```

Start an LSP server:

```shell-session
$ rufffmt lsp
```


License
-------

rufffmt is copyright Amethyst Reese, and licensed under the MIT license.
